@@ -25,6 +25,7 @@
 
 #include "gtksourcestylescheme.h"
 #include "gtksourcestyleschememanager.h"
+#include "gtksourcestyle.h"
 #include "gtksourcestyle-private.h"
 #include "gtksourceview.h"
 #include "gtksourcelanguage-private.h"
@@ -41,10 +42,14 @@
  * #GtkSourceStyleScheme contains all the text styles to be used in
  * #GtkSourceView and #GtkSourceBuffer. For instance, it contains text styles
  * for syntax highlighting, it may contain foreground and background color for
- * non-highlighted text, color for the line numbers, etc.
+ * non-highlighted text, color for the line numbers, current line highlighting,
+ * bracket matching, etc.
  *
  * Style schemes are stored in XML files. The format of a scheme file is
  * documented in the [style scheme reference][style-reference].
+ *
+ * The two style schemes with IDs "classic" and "tango" follow more closely the
+ * GTK+ theme (for example for the background color).
  */
 
 #define STYLE_TEXT			"text"
@@ -757,10 +762,8 @@ get_css_provider_cursors (GtkSourceStyleScheme *scheme,
 	if (error != NULL)
 	{
 		g_warning ("Error when loading CSS for cursors: %s", error->message);
-		g_error_free (error);
-
-		g_object_unref (provider);
-		return NULL;
+		g_clear_error (&error);
+		g_clear_object (&provider);
 	}
 
 	return provider;
@@ -817,7 +820,7 @@ _gtk_source_style_scheme_apply (GtkSourceStyleScheme *scheme,
 
 /**
  * _gtk_source_style_scheme_unapply:
- * @scheme: (allow-none): a #GtkSourceStyleScheme or %NULL.
+ * @scheme: (nullable): a #GtkSourceStyleScheme or %NULL.
  * @view: a #GtkSourceView to unapply styles to.
  *
  * Removes the styles from @scheme in the @view.
@@ -963,13 +966,15 @@ generate_css_style (GtkSourceStyleScheme *scheme)
 	{
 		GError *error = NULL;
 
-		if (!gtk_css_provider_load_from_data (scheme->priv->css_provider,
-		                                      final_style->str,
-		                                      final_style->len,
-		                                      &error))
+		gtk_css_provider_load_from_data (scheme->priv->css_provider,
+						 final_style->str,
+						 final_style->len,
+						 &error);
+
+		if (error != NULL)
 		{
 			g_warning ("%s", error->message);
-			g_error_free (error);
+			g_clear_error (&error);
 		}
 	}
 
@@ -1360,7 +1365,7 @@ _gtk_source_style_scheme_new_from_file (const gchar *filename)
 		g_warning ("could not load style scheme file '%s': %s",
 			   filename_utf8, error->message);
 		g_free (filename_utf8);
-		g_error_free (error);
+		g_clear_error (&error);
 		return NULL;
 	}
 
@@ -1398,9 +1403,8 @@ _gtk_source_style_scheme_new_from_file (const gchar *filename)
 		g_warning ("could not load style scheme file '%s': %s",
 			   filename_utf8, error->message);
 		g_free (filename_utf8);
-		g_error_free (error);
-		g_object_unref (scheme);
-		scheme = NULL;
+		g_clear_error (&error);
+		g_clear_object (&scheme);
 	}
 	else
 	{
