@@ -227,7 +227,7 @@ load_cb (GtkSourceFileLoader *loader,
 	if (error != NULL)
 	{
 		g_warning ("Error while loading the file: %s", error->message);
-		g_error_free (error);
+		g_clear_error (&error);
 		g_clear_object (&self->priv->file);
 		goto end;
 	}
